@@ -1,21 +1,28 @@
-import matplotlib.pyplot as plt
-import numpy as np
-import pandas as pd
 from copy import deepcopy
 from functools import partial
-from sklearn.base import BaseEstimator
-from sklearn.base import BaseEstimator, ClassifierMixin, RegressorMixin, MetaEstimatorMixin
+
+import numpy as np
+from sklearn.base import BaseEstimator, ClassifierMixin, MetaEstimatorMixin
+from sklearn.preprocessing import normalize
 from sklearn.tree import DecisionTreeClassifier
-from sklearn.utils.multiclass import check_classification_targets
+from sklearn.utils.multiclass import check_classification_targets, unique_labels
 from sklearn.utils.validation import check_X_y, check_array, check_is_fitted
 
 from imodels.rule_set.rule_set import RuleSet
-from imodels.util.convert import tree_to_code
+from imodels.rule_set.slipper_util import SlipperBaseEstimator
+from imodels.util.convert import tree_to_code, tree_to_rules, dict_to_rule
+from imodels.util.rule import Rule, get_feature_dict, replace_feature_name
 
 
-class BoostedRulesClassifier(BaseEstimator, RuleSet, MetaEstimatorMixin):
+class BoostedRulesClassifier(RuleSet, BaseEstimator, MetaEstimatorMixin, ClassifierMixin):
     '''An easy-interpretable classifier optimizing simple logical rules.
     Currently limited to only binary classification.
+    
+    Params
+    ------
+    estimator: object with fit and predict methods
+        Defaults to DecisionTreeClassifier with AdaBoost.
+        For SLIPPER, should pass estimator=imodels.SlipperBaseEstimator
     '''
 
     def __init__(self, n_estimators=10, estimator=partial(DecisionTreeClassifier, max_depth=1)):
@@ -48,7 +55,14 @@ class BoostedRulesClassifier(BaseEstimator, RuleSet, MetaEstimatorMixin):
         """
 
         X, y = check_X_y(X, y)
-        self.n_features_in_ = X.shape[1]
+        check_classification_targets(y)
+        self.n_features_ = X.shape[1]
+        self.classes_ = unique_labels(y)
+
+        self.feature_dict_ = get_feature_dict(X.shape[1], feature_names)
+        self.feature_placeholders = list(self.feature_dict_.keys())
+        self.feature_names = list(self.feature_dict_.values())
+
         n_train = y.shape[0]
         w = np.ones(n_train) / n_train
         self.estimators_ = []
@@ -83,12 +97,35 @@ class BoostedRulesClassifier(BaseEstimator, RuleSet, MetaEstimatorMixin):
             self.estimators_.append(deepcopy(clf))
             self.estimator_weights_.append(alpha_m)
             self.estimator_errors_.append(err_m)
-        self.complexity_ = len(self.estimators_)
+
+        rules = []
+
+        for est, est_weight in zip(self.estimators_, self.estimator_weights_):
+            if type(clf) == DecisionTreeClassifier:
+                est_rules_values = tree_to_rules(est, self.feature_placeholders, prediction_values=True)
+                est_rules = list(map(lambda x: x[0], est_rules_values))
+
+                # BRS scores are difference between class 1 % and class 0 % in a node
+                est_values = np.array(list(map(lambda x: x[1], est_rules_values)))
+                rule_scores = (est_values[:, 1] - est_values[:, 0]) / est_values.sum(axis=1)
+
+                compos_score = est_weight * rule_scores
+                rules += [Rule(r, args=[w]) for (r, w) in zip(est_rules, compos_score)]
+
+            if type(clf) == SlipperBaseEstimator:
+                # SLIPPER uses uniform confidence over in rule observations
+                est_rule = dict_to_rule(est.rule, est.feature_dict)
+                rules += [Rule(est_rule, args=[est_weight])]
+
+        self.rules_without_feature_names_ = rules
+        self.rules_ = [
+            replace_feature_name(rule, self.feature_dict_) for rule in self.rules_without_feature_names_
+        ]
+        self.complexity_ = self._get_complexity()
         return self
 
     def predict_proba(self, X):
-        '''Predict probabilities for X
-        '''
+        ''' Predict probabilities for X '''
         check_is_fitted(self)
         X = check_array(X)
 
@@ -97,17 +134,17 @@ class BoostedRulesClassifier(BaseEstimator, RuleSet, MetaEstimatorMixin):
         n_estimators = len(self.estimators_)
         n_classes = 2  # hard-coded for now!
         preds = np.zeros((n_train, n_classes))
-        # print('shapes', preds.shape, self.estimator_weights_[0], self.estimators_[0].predict_proba(X).shape)
         for i in range(n_estimators):
             preds += self.estimator_weights_[i] * self.estimators_[i].predict_proba(X)
-        return preds / n_estimators
+        pred_values = preds / n_estimators
+        return normalize(pred_values, norm='l1')
 
     def predict(self, X):
         """Predict outcome for X
         """
         check_is_fitted(self)
         X = check_array(X)
-        return self.predict_proba(X).argmax(axis=1)
+        return self.eval_weighted_rule_sum(X) > 0
 
     def __str__(self):
         try:
